@@ -102,8 +102,9 @@ sub fill_package_cache ($self, $c) {
                         s/:\w+//;    # remove arch qualifier
                         $_;
                     }
+                    grep { $_ }      # skip empty data
                     map { split /\s*[,|]\s*/ , $_->[0] } # extract dependency info from array ref
-                    grep { ref $_ } # skip emtpy data
+                    grep { ref $_ } # skip empty section
                     $section{$found}->@*;
             }
         }
