@@ -18,6 +18,7 @@ use DB_File ;
 use Log::Log4perl qw(get_logger :levels);
 use Module::CoreList;
 use JSON;
+use Path::Tiny;
 use version ;
 
 use Parse::RecDescent ;
@@ -732,11 +733,16 @@ sub warn_or_remove_dep {
 use vars qw/%cache $use_test_cache/ ;
 
 # Set up persistence
-my $cache_file_name = $ENV{HOME}.'/.config_model_depend_cache' ;
+my $xdg_cache_dir = path($ENV{XDG_CACHE_HOME} || '~/.cache');
+
+my $cache_file = $xdg_cache_dir->child('cme_dpkg_dependency') ;
 
 # this condition is used during tests
 if (not $use_test_cache) {
-    tie %cache => 'DB_File', $cache_file_name,
+    # remove old cache file, this line can be removed in 2020
+    path($ENV{HOME}.'/.config_model_depend_cache')->remove;
+
+    tie %cache => 'DB_File', $cache_file->stringify,
 }
 
 # required to write data back to DB_File
