@@ -306,6 +306,13 @@ our @tests = (
         check => {
             'source Build-Depends:1' => 'perl:any',
         }
+    },
+    {
+        name => 'npm2deb_package',
+        check => {
+            'source Build-Depends:0' => 'debhelper (>= 11~)',
+            'source Build-Depends:1' => 'nodejs',
+        }
     }
 );
 
